<?php

namespace Drupal\restrict_route_by_ip\Service;

use Drupal\Core\Session\AccountInterface;

/**
 * Restrict Ip Interface.
 */
interface RestrictIpInterface {

  /**
   * Check a range of IP.
   *
   * @param string $ip
   *   IP to check.
   * @param string $range
   *   IP range authorized.
   *
   * @return bool
   *   TRUE if the IP to check is in the range.
   */
  public function checkRangeIp(string $ip, string $range): bool;

  /**
   * Check if the current user IP has a restricted access.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Current account.
   *
   * @return bool
   *   TRUE if access must be restricted.
   */
  public function userIpIsRestricted(AccountInterface $account): bool;

  /**
   * Get all enabled restricted routes.
   *
   * @return array
   *    List of all routes.
   */
  public function getAllRestrictedRoutes(): array;

}
